==> nextcloud-app-mail-3.2.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ko.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "포함된 메시지 %s",
    "Important mail" : "중요 메일",
    "Unread mail" : "읽지 않은 메일",
    "Important" : "중요",
    "Work" : "직장",
    "Personal" : "개인",
    "Later" : "나중에",
    "Mails" : "메일",
    "Mail" : "메일",
    "💌 A mail app for Nextcloud" : "Nextcloud 메일 앱",
    "Drafts are saved in:" : "초안은 다음 위치에 저장:",
    "Sent messages are saved in:" : "보낸 메시지는 다음 위치에 저장:",
    "Deleted messages are moved in:" : "삭제된 메시지는 다음 위치로 이동:",
    "Auto" : "자동",
    "Name" : "이름",
    "Mail address" : "메일 주소",
    "Please enter an email of the format name@example.com" : "name@example.com 형식의 이메일을 입력하세요.",
    "Password" : "암호",
    "Manual" : "수동",
    "IMAP Settings" : "IMAP 설정",
    "IMAP Host" : "IMAP 호스트",
    "IMAP Security" : "IMAP 보안",
    "None" : "없음",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 포트",
    "IMAP User" : "IMAP 사용자",
    "IMAP Password" : "IMAP 암호",
    "SMTP Settings" : "SMTP 설정",
    "SMTP Host" : "SMTP 호스트",
    "SMTP Security" : "SMTP 보안",
    "SMTP Port" : "SMTP 포트",
    "SMTP User" : "SMTP 사용자",
    "SMTP Password" : "SMTP 암호",
    "Connecting" : "연결 중",
    "Save" : "저장",
    "Connect" : "연결",
    "Password required" : "암호가 필요함",
    "Account updated" : "계정 업데이트됨",
    "There was an error while setting up your account" : "계정을 설정하는 중 오류가 발생했습니다",
    "Account settings" : "계정 설정",
    "Signature" : "서명",
    "A signature is added to the text of new messages and replies." : "서명이 새로운 메시지 및 전달 메시지의 텍스트에 추가됩니다.",
    "Writing mode" : "쓰기 모드",
    "Preferred writing mode for new messages and replies." : "새 메시지 및 답장을 위한 기본 쓰기 모드입니다.",
    "Default folders" : "기본 폴더",
    "Trusted senders" : "신뢰할 수 있는 발신자",
    "Mail server" : "메일 서버",
    "Go back" : "뒤로 가기",
    "Change name" : "이름 변경",
    "Email address" : "이메일 주소",
    "Add alias" : "별칭 추가",
    "Cancel" : "취소",
    "Add mail account" : "메일 계정 추가",
    "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
    "Register as application for mail links" : "메일 링크를 어플리케이션으로 등록",
    "Show keyboard shortcuts" : "키보드 단축키 표시",
    "Looking for a way to encrypt your emails?" : "이메일을 암호화하는 방법을 찾고 계십니까?",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "앱이 상호 작용에 대한 데이터를 수집하도록 허용합니다. 이 데이터를 기반으로 앱이 사용자의 기본 설정에 맞게 조정됩니다. 데이터는 로컬에만 저장됩니다.",
    "Put my text to the bottom of a reply instead of on top of it." : "내 텍스트를 답장 위가 아니라 답장 맨 아래에 놓기",
    "Automatically classify importance of new email" : "새 이메일의 중요도 자동 분류",
    "Could not update preference" : "환경설정을 업데이트할 수 없습니다.",
    "From" : "보낸사람",
    "Select account" : "계정 선택",
    "To" : "받는사람",
    "Contact or email address …" : "연락처 또는 이메일 주소 ...",
    "Toggle recipients list mode" : "수신자 목록 모드 전환",
    "Cc" : "참조",
    "Bcc" : "숨은참조",
    "No contacts found." : "연락처를 찾을 수 없음",
    "Subject" : "제목",
    "Subject …" : "제목...",
    "The following recipients do not have a PGP key: {recipients}." : "다음의 수신자는 PGP key가 없습니다:{recipients}.",
    "Write message …" : "메시지 작성중...",
    "Saving draft …" : "초안 저장 중...",
    "Error saving draft" : "초안을 저장하는 중에 오류가 발생했습니다.",
    "Draft saved" : "초안 저장됨",
    "Save draft" : "초안 저장",
    "Upload attachment" : "첨부 파일 업로드",
    "Add attachment from Files" : "파일 앱에서 첨부 파일 추가",
    "Send later" : "나중에 보내기",
    "Enable formatting" : "서식 활성화",
    "Request a read receipt" : "수신 확인 요청",
    "Encrypt message with Mailvelope" : "Mailvelope로 메세지 암호화",
    "Send now" : "지금 보내기",
    "Tomorrow morning" : "내일 아침",
    "Tomorrow afternoon" : "내일 오후",
    "Monday morning" : "월요일 아침",
    "Custom date and time" : "사용자 지정 날짜 및 시간",
    "Enter a date" : "날짜 입력",
    "Send" : "보내기",
    "Choose a file to add as attachment" : "첨부할 파일을 선택하십시오",
    "Choose a file to share as a link" : "공유할 링크 파일을 선택하십시오",
    "Confirm" : "확인",
    "Set up an account" : "계정 설정",
    "Plain text" : "평문",
    "Rich text" : "서식 있는 텍스트",
    "No messages" : "메시지가 없음",
    "Draft: " : "임시 보관함",
    "Unfavorite" : "즐겨찾기에서 삭제",
    "Favorite" : "즐겨찾기",
    "Read" : "읽기",
    "Mark not spam" : "스팸 해제",
    "Mark as spam" : "스팸 신고",
    "Unselect" : "선택 해제",
    "Select" : "선택",
    "Edit tags" : "태그 편집",
    "More actions" : "더 많은 동작",
    "Create event" : "일정 만들기",
    "Forward" : "전달",
    "Load more" : "더 불러오기",
    "Report this bug" : "이 오류 보고",
    "All day" : "하루 종일",
    "Create" : "생성",
    "Comment" : "설명",
    "Accept" : "수락",
    "Decline" : "거절",
    "More options" : "더 많은 옵션",
    "Could not open mailbox" : "메일함을 열 수 없음",
    "Choose" : "선택",
    "Important info" : "중요 정보",
    "Other" : "기타",
    "Reply" : "답장",
    "Import into calendar" : "달력으로 가져오기",
    "Download attachment" : "첨부 파일 다운로드",
    "Save to Files" : "파일에 저장",
    "Unnamed" : "이름 없음",
    "Choose a folder to store the attachment in" : "첨부 항목을 저장할 폴더 선택",
    "Save all to Files" : "모두 저장",
    "The images have been blocked to protect your privacy." : "개인 정보를 보호하기 위해 사진을 차단했습니다.",
    "Show images" : "사진 보이기",
    "Move" : "이동",
    "Quota" : "할당량",
    "Saving" : "저장 중",
    "Move up" : "위로 이동",
    "Move down" : "아래로 이동",
    "Remove account" : "계정 삭제",
    "Loading …" : "불러오는 중 …",
    "Remove account {email}" : "{email} 계정 제거",
    "Remove {email}" : "{email} 제거",
    "Mark all as read" : "모두 읽은 것으로 표시",
    "Edit name" : "이름 편집",
    "Clear cache" : "Clear cache",
    "Subscribed" : "구독함",
    "_{total} message_::_{total} messages_" : ["{total} 개의 메시지"],
    "New message" : "새로운 메시지",
    "Refresh" : "새로 고침",
    "Error sending your message" : "당신의 메시지 보내기 오류",
    "Retry" : "다시 시도",
    "Uploading attachments …" : "첨부 파일 업로드...",
    "Sending …" : "보내는 중...",
    "Warning sending your message" : "메시지 전송 경고",
    "Message" : "메시지",
    "Delete" : "삭제",
    "Copy to clipboard" : "클립보드로 복사",
    "Add" : "추가",
    "Close" : "닫기",
    "Tags" : "태그",
    "Select tags" : "태그 선택",
    "Clear" : "비우기",
    "Search" : "검색",
    "Date" : "날짜",
    "Disabled" : "비활성화됨",
    "Enabled" : "활성화됨",
    "Custom" : "사용자 정의",
    "Signature …" : "서명 …",
    "Save signature" : "서명 저장",
    "Add tag" : "태그 추가",
    "Tag already exists" : "태그가 이미 존재합니다",
    "Not found" : "찾을 수 없음",
    "Unsubscribe" : "구독 취소",
    "Mark as unread" : "읽지 않은 것으로 표시",
    "Mark as read" : "읽은 것으로 표시",
    "Remove" : "삭제",
    "Untitled event" : "제목 없는 일정",
    "Airplane" : "여객기",
    "Reservation {id}" : "예약 {id}",
    "Train" : "열차",
    "The mail app allows users to read mails on their IMAP accounts." : "Mail 앱은 사용자가 자신의 IMAP 계정에서 이메일을 읽을 수 있도록 합니다.",
    "Allow additional mail accounts" : "추가 이메일 계정 허용",
    "Allow additional Mail accounts from User Settings" : "사용자 설정에서 추가 이메일 계정 설정을 허용",
    "Reset" : "초기화",
    "Client ID" : "클라이언트 ID",
    "Client secret" : "클라이언트 비밀 값",
    "General" : "일반",
    "IMAP" : "IMAP",
    "User" : "사용자",
    "Host" : "호스트",
    "Port" : "포트",
    "SMTP" : "SMTP",
    "With the settings above, the app will create account settings in the following way:" : "상단의 설정을 통해, 앱은 다음의 방법으로 계정 설정을 생성합니다: ",
    "E-mail address" : "이메일 주소",
    "Valid until" : "만료 기간:",
    "Certificate" : "인증서",
    "Back" : "뒤로",
    "Submit" : "제출",
    "Keyboard shortcut" : "키보드 단축키",
    "Keyboard shortcuts" : "키보드 단축키",
    "Speed up your Mail experience with these quick shortcuts." : "빠른 단축키로 메일 사용을 더 빠르게 할 수 있습니다.",
    "Compose new message" : "새 메시지 작성",
    "Newer message" : "새로운 메시지",
    "Older message" : "오래된 메시지",
    "Toggle star" : "별표 전환",
    "Toggle unread" : "읽음/읽지 않음 전환",
    "Archive" : "보관",
    "Account connected" : "계정 연결됨",
    "Connect your mail account" : "메일 계정에 연결",
    "To add a mail account, please contact your administrator." : "이메일 계정 추가는 관리자에게 문의하십시오.",
    "All" : "모두",
    "Drafts" : "임시 보관함",
    "Favorites" : "즐겨찾기",
    "Priority inbox" : "우선 받은편지함",
    "All inboxes" : "모든 받은 편지함",
    "Inbox" : "받은 편지함",
    "Junk" : "스팸 메일함",
    "Sent" : "보낸 편지함",
    "Trash" : "휴지통",
    "Error while sharing file" : "파일 공유하는 도중 오류",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["새 메일 %n개\n보낸 사람: {from}"],
    "Nextcloud Mail" : "Nextcloud 메일",
    "Message sent" : "보낸 메시지",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러올 수 없음",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러오는 중 문제 발생",
    "Could not load your message" : "메시지를 불러올 수 없음",
    "Could not load the desired message" : "원하는 메시지를 불러올 수 없음",
    "Could not load the message" : "메시지를 불러올 수 없음",
    "Error loading message" : "메시지 불러오기 오류",
    "Forwarding to %s" : "%s 전달",
    "Click here if you are not automatically redirected within the next few seconds." : "자동으로 이동하지 않는 경우 여기를 클릭하십시오.",
    "Redirect" : "넘겨주기",
    "The link leads to %s" : "이 링크가 %s을(를) 향함",
    "Continue to %s" : "%s(으)로 이동"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-3.4.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ko.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "포함된 메시지 %s",
    "Important mail" : "중요 메일",
    "Unread mail" : "읽지 않은 메일",
    "Important" : "중요",
    "Work" : "직장",
    "Personal" : "개인",
    "Later" : "나중에",
    "Mail" : "메일",
    "Mails" : "메일",
    "💌 A mail app for Nextcloud" : "Nextcloud 메일 앱",
    "Drafts are saved in:" : "초안은 다음 위치에 저장:",
    "Sent messages are saved in:" : "보낸 메시지는 다음 위치에 저장:",
    "Deleted messages are moved in:" : "삭제된 메시지는 다음 위치로 이동:",
    "Auto" : "자동",
    "Name" : "이름",
    "Mail address" : "메일 주소",
    "Please enter an email of the format name@example.com" : "name@example.com 형식의 이메일을 입력하세요.",
    "Password" : "암호",
    "Manual" : "수동",
    "IMAP Settings" : "IMAP 설정",
    "IMAP Host" : "IMAP 호스트",
    "IMAP Security" : "IMAP 보안",
    "None" : "없음",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 포트",
    "IMAP User" : "IMAP 사용자",
    "IMAP Password" : "IMAP 암호",
    "SMTP Settings" : "SMTP 설정",
    "SMTP Host" : "SMTP 호스트",
    "SMTP Security" : "SMTP 보안",
    "SMTP Port" : "SMTP 포트",
    "SMTP User" : "SMTP 사용자",
    "SMTP Password" : "SMTP 암호",
    "Connecting" : "연결 중",
    "Save" : "저장",
    "Connect" : "연결",
    "Password required" : "암호가 필요함",
    "Account updated" : "계정 업데이트됨",
    "There was an error while setting up your account" : "계정을 설정하는 중 오류가 발생했습니다.",
    "Account settings" : "계정 설정",
    "Aliases" : "별칭",
    "Signature" : "서명",
    "A signature is added to the text of new messages and replies." : "서명이 새로운 메시지 및 전달 메시지의 텍스트에 추가됩니다.",
    "Writing mode" : "쓰기 모드",
    "Preferred writing mode for new messages and replies." : "새 메시지 및 답장을 위한 기본 쓰기 모드입니다.",
    "Default folders" : "기본 폴더",
    "Trusted senders" : "신뢰할 수 있는 발신자",
    "Mail server" : "메일 서버",
    "Go back" : "뒤로 가기",
    "Change name" : "이름 변경",
    "Email address" : "이메일 주소",
    "Add alias" : "별칭 추가",
    "Cancel" : "취소",
    "Add mail account" : "메일 계정 추가",
    "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
    "Register as application for mail links" : "메일 링크를 어플리케이션으로 등록",
    "Show keyboard shortcuts" : "키보드 단축키 표시",
    "Looking for a way to encrypt your emails?" : "이메일을 암호화하는 방법을 찾고 계십니까?",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "앱이 상호 작용에 대한 데이터를 수집하도록 허용합니다. 이 데이터를 기반으로 앱이 사용자의 기본 설정에 맞게 조정됩니다. 데이터는 로컬에만 저장됩니다.",
    "Put my text to the bottom of a reply instead of on top of it." : "내 텍스트를 답장 위가 아니라 답장 맨 아래에 놓기",
    "Automatically classify importance of new email" : "새 이메일의 중요도 자동 분류",
    "Could not update preference" : "환경설정을 업데이트할 수 없습니다.",
    "From" : "보낸사람",
    "Select account" : "계정 선택",
    "To" : "받는사람",
    "Contact or email address …" : "연락처 또는 이메일 주소 ...",
    "Toggle recipients list mode" : "받는이 목록 모드 전환",
    "Cc" : "참조",
    "Bcc" : "숨은참조",
    "No contacts found." : "연락처를 찾을 수 없음",
    "Subject" : "제목",
    "Subject …" : "제목...",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "다음 받는이가 S/MIME 인증서를 가지고 있지 않습니다: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "다음의 받는이는 PGP key가 없습니다:{recipients}.",
    "Write message …" : "메시지 작성중...",
    "Saving draft …" : "초안 저장 중...",
    "Error saving draft" : "초안을 저장하는 중에 오류가 발생했습니다.",
    "Draft saved" : "초안 저장됨",
    "Save draft" : "초안 저장",
    "Upload attachment" : "첨부 파일 업로드",
    "Add attachment from Files" : "파일 앱에서 첨부 파일 추가",
    "Send later" : "나중에 보내기",
    "Enable formatting" : "서식 활성화",
    "Request a read receipt" : "수신 확인 요청",
    "Encrypt message with Mailvelope" : "Mailvelope로 메시지 암호화",
    "Send now" : "지금 보내기",
    "Tomorrow morning" : "내일 아침",
    "Tomorrow afternoon" : "내일 오후",
    "Monday morning" : "월요일 아침",
    "Custom date and time" : "사용자 지정 날짜 및 시간",
    "Enter a date" : "날짜 입력",
    "Send" : "보내기",
    "Choose a file to add as attachment" : "첨부할 파일을 선택하십시오",
    "Choose a file to share as a link" : "공유할 링크 파일을 선택하세요.",
    "Confirm" : "확인",
    "Set up an account" : "계정 설정",
    "Plain text" : "평문",
    "Rich text" : "서식 있는 텍스트",
    "No messages" : "메시지가 없음",
    "Draft: " : "임시 보관함",
    "Unfavorite" : "즐겨찾기에서 삭제",
    "Favorite" : "즐겨찾기",
    "Read" : "읽기",
    "Mark not spam" : "스팸 해제",
    "Mark as spam" : "스팸 신고",
    "Unselect" : "선택 해제",
    "Select" : "선택",
    "Edit tags" : "태그 편집",
    "More actions" : "더 많은 동작",
    "Back" : "뒤로",
    "Create event" : "일정 만들기",
    "Set reminder for later today" : "알림을 오늘 나중에 설정",
    "Set reminder for tomorrow" : "알림을 내일로 설정",
    "Set reminder for this weekend" : "알림을 주말로 설정",
    "Set reminder for next week" : "알림을 다음주로 설정",
    "Forward" : "전달",
    "Load more" : "더 불러오기",
    "Report this bug" : "이 오류 보고",
    "All day" : "하루 종일",
    "Create" : "생성",
    "Comment" : "설명",
    "Accept" : "수락",
    "Decline" : "거절",
    "More options" : "더 많은 옵션",
    "Could not open mailbox" : "메일함을 열 수 없음",
    "Choose" : "선택",
    "Important info" : "중요 정보",
    "Other" : "기타",
    "Reply" : "답장",
    "Import into calendar" : "달력으로 가져오기",
    "Download attachment" : "첨부 파일 다운로드",
    "Save to Files" : "파일에 저장",
    "Unnamed" : "이름 없음",
    "Next week – {timeLocale}" : "다음주 – {timeLocale}",
    "Choose a folder to store the attachment in" : "첨부 항목을 저장할 폴더 선택",
    "Save all to Files" : "모두 저장",
    "The images have been blocked to protect your privacy." : "개인 정보를 보호하기 위해 사진을 차단했습니다.",
    "Show images" : "사진 보이기",
    "Move" : "이동",
    "Quota" : "할당량",
    "Saving" : "저장 중",
    "Move up" : "위로 이동",
    "Move down" : "아래로 이동",
    "Remove account" : "계정 삭제",
    "Loading …" : "불러오는 중 …",
    "{usage} of {limit} used" : "{limit} 중 {usage} 사용중",
    "Remove account {email}" : "{email} 계정 제거",
    "Remove {email}" : "{email} 제거",
    "Mark all as read" : "모두 읽은 것으로 표시",
    "Edit name" : "이름 편집",
    "Clear cache" : "Clear cache",
    "Subscribed" : "구독함",
    "_{total} message_::_{total} messages_" : ["{total} 개의 메시지"],
    "New message" : "새로운 메시지",
    "Refresh" : "새로 고침",
    "Error sending your message" : "당신의 메시지 보내기 오류",
    "Retry" : "다시 시도",
    "Uploading attachments …" : "첨부 파일 업로드...",
    "Sending …" : "보내는 중...",
    "Warning sending your message" : "메시지 전송 경고",
    "Message" : "메시지",
    "Delete" : "삭제",
    "Copy to clipboard" : "클립보드로 복사",
    "Add" : "추가",
    "Close" : "닫기",
    "Select recipients" : "받는이 선택",
    "Select CC recipients" : "CC 받는이 선택",
    "Select BCC recipients" : "BCC 받는이 선택",
    "Tags" : "태그",
    "Select tags" : "태그 선택",
    "Clear" : "비우기",
    "Search" : "검색",
    "Date" : "날짜",
    "Disabled" : "비활성화됨",
    "Enabled" : "활성화됨",
    "Custom" : "사용자 정의",
    "This weekend – {timeLocale}" : "이번 주말 – {timeLocale}",
    "Signature …" : "서명 …",
    "Save signature" : "서명 저장",
    "Add tag" : "태그 추가",
    "Tag already exists" : "태그가 이미 존재합니다.",
    "Not found" : "찾을 수 없음",
    "Unsubscribe" : "구독 취소",
    "Mark as unread" : "읽지 않은 것으로 표시",
    "Mark as read" : "읽은 것으로 표시",
    "Remove" : "삭제",
    "Untitled event" : "제목 없는 일정",
    "Airplane" : "여객기",
    "Reservation {id}" : "예약 {id}",
    "Train" : "열차",
    "The mail app allows users to read mails on their IMAP accounts." : "Mail 앱은 사용자가 자신의 IMAP 계정에서 이메일을 읽을 수 있도록 합니다.",
    "Allow additional mail accounts" : "추가 이메일 계정 허용",
    "Allow additional Mail accounts from User Settings" : "사용자 설정에서 추가 이메일 계정 설정을 허용",
    "Reset" : "초기화",
    "Client ID" : "클라이언트 ID",
    "Client secret" : "클라이언트 비밀 값",
    "General" : "일반",
    "IMAP" : "IMAP",
    "User" : "사용자",
    "Host" : "호스트",
    "Port" : "포트",
    "SMTP" : "SMTP",
    "With the settings above, the app will create account settings in the following way:" : "상단의 설정을 통해, 앱은 다음의 방법으로 계정 설정을 생성합니다: ",
    "E-mail address" : "이메일 주소",
    "Valid until" : "만료 기간:",
    "Certificate" : "인증서",
    "Submit" : "제출",
    "Keyboard shortcut" : "키보드 단축키",
    "Keyboard shortcuts" : "키보드 단축키",
    "Speed up your Mail experience with these quick shortcuts." : "빠른 단축키로 메일 사용을 더 빠르게 할 수 있습니다.",
    "Compose new message" : "새 메시지 작성",
    "Newer message" : "새로운 메시지",
    "Older message" : "오래된 메시지",
    "Toggle star" : "별표 전환",
    "Toggle unread" : "읽음/읽지 않음 전환",
    "Archive" : "보관",
    "Account connected" : "계정 연결됨",
    "Connect your mail account" : "메일 계정에 연결",
    "To add a mail account, please contact your administrator." : "이메일 계정 추가는 관리자에게 문의하십시오.",
    "All" : "모두",
    "Drafts" : "임시 보관함",
    "Favorites" : "즐겨찾기",
    "Priority inbox" : "우선 받은편지함",
    "All inboxes" : "모든 받은 편지함",
    "Inbox" : "받은 편지함",
    "Junk" : "스팸 메일함",
    "Sent" : "보낸 편지함",
    "Trash" : "휴지통",
    "Error while sharing file" : "파일 공유하는 도중 오류 발생",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["새 메일 %n개\n보낸 사람: {from}"],
    "Nextcloud Mail" : "Nextcloud 메일",
    "Message sent" : "보낸 메시지",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러올 수 없음",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러오는 중 문제 발생",
    "Could not load your message" : "메시지를 불러올 수 없음",
    "Could not load the desired message" : "원하는 메시지를 불러올 수 없음",
    "Could not load the message" : "메시지를 불러올 수 없음",
    "Error loading message" : "메시지 불러오기 오류",
    "Forwarding to %s" : "%s 전달",
    "Click here if you are not automatically redirected within the next few seconds." : "자동으로 이동하지 않는 경우 여기를 클릭하십시오.",
    "Redirect" : "넘겨주기",
    "The link leads to %s" : "이 링크가 %s을(를) 향함",
    "Continue to %s" : "%s(으)로 이동"
},
"nplurals=1; plural=0;");
